pub struct KernelInvocationBuilder<'a, 'b> { /* private fields */ }Expand description
A builder-pattern constructor for kernel invocations.
Implementations
Sourceimpl<'a, 'b> KernelInvocationBuilder<'a, 'b>
impl<'a, 'b> KernelInvocationBuilder<'a, 'b>
Sourcepub fn new(
queue: &'b mut KernelInvocationQueue<'a>,
pipeline: &'a ComputePipeline,
) -> Self
pub fn new( queue: &'b mut KernelInvocationQueue<'a>, pipeline: &'a ComputePipeline, ) -> Self
Initiates the creation of a kernel invocation for the given compute pipeline.
Note that the invocation will not be queued into queue until
KernelInvocationBuilder::queue or KernelInvocationBuilder::queue_indirect is called.
Sourcepub fn bind0<const INPUTS: usize>(self, inputs: [&Buffer; INPUTS]) -> Self
pub fn bind0<const INPUTS: usize>(self, inputs: [&Buffer; INPUTS]) -> Self
Binds INPUTS consecutive buffers to the bind group with id 0.
This method is less versatile than Self::bind and Self::bind_at but covers one
of the most common cases. This will bind ipunts[i] to the storage binding i of bind
group 0.
Sourcepub fn bind<const INPUTS: usize>(
self,
bind_group_id: u32,
inputs: [&Buffer; INPUTS],
) -> Self
pub fn bind<const INPUTS: usize>( self, bind_group_id: u32, inputs: [&Buffer; INPUTS], ) -> Self
Binds INPUTS consecutive buffers to the bind group with id bind_group_id.
This method is more versatile than Self::bind0, but less than Self::bind_at. This
will bind ipunts[i] to the storage binding i of bind group bind_group_id.
Sourcepub fn bind_at<const INPUTS: usize>(
self,
bind_group_id: u32,
inputs: [(&Buffer, u32); INPUTS],
) -> Self
pub fn bind_at<const INPUTS: usize>( self, bind_group_id: u32, inputs: [(&Buffer, u32); INPUTS], ) -> Self
Binds INPUTS buffers with arbitrary storage binding ids, to the bind group with id
bind_group_id.
This method is more versatile than Self::bind0, and Self::bind. This
will bind inputs[i].0 to the storage binding inputs[i].1 of bind group bind_group_id.
Sourcepub fn queue(self, workgroups: impl WorkgroupSize)
pub fn queue(self, workgroups: impl WorkgroupSize)
Queues the kernel invocation into the queue that was given to
KernelInvocationQueue::new.
The invocation will be configured with the given workgroups size (typically specified as
a single u32 or a [u32; 3]).
Sourcepub fn queue_indirect(self, workgroups: Arc<Buffer>)
pub fn queue_indirect(self, workgroups: Arc<Buffer>)
Queues the indirect kernel invocation into the queue that was given to
KernelInvocationQueue::new.
The invocation will be configured with an indirect workgroups size specified with a
Buffer that must contain exactly one instance of wgpu::util::DispatchIndirectArgs.