Module shapes

Module shapes 

Tensor shape definition.

Structs

ViewShape
The shape of a matrix view over a GPU tensor.
ViewShapeBuffers
A map between a ViewShape and an uniform storage Buffer containing its value on the gpu.