Tensor shape definition.
Structs
- View
Shape - The shape of a matrix view over a GPU tensor.
- View
Shape Buffers - A map between a
ViewShapeand an uniform storageBuffercontaining its value on the gpu.
Tensor shape definition.
ViewShape and an uniform storage Buffer containing its value on the gpu.